---
name: Bug report
about: Report an error which requires fixing
title: ''
labels: Bug

---

**Description of the error**
A clear and concise description of what the problem is, including steps to reproduce it and the environment you are running FitBenchmarking in.

**Describe the expected result**
What is the result you expect from running the steps described above?

**Describe the actual result**
What was the actual result.

**Suggested fix**

**Additional details**
Add any other context or screenshots about the feature request here.
